#' @name PaulinoTb6.2
#' @title Pacientes com Complicação Pulmonar 
#' @description Estudo envolvendo a avaliação pulmonar pré-operatória de
#'     1162 pacientes e a ocorrência de complicação pulmonar no
#'     pós-operatório de cirurgia geral. 
#' @format Um \code{data.frame} com 6 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{preop}}{Avaliação pré-operatória do grau de complicação
#'     pulmonar.}
#'
#' \item{\code{posop}}{Avalição pulmonar pós-operatória (sem ou com
#'     complicação).}
#'
#' \item{\code{npaci}}{Número de pacientes.}
#'
#' }
#' @keywords binomial contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 6.2, pág. 150).
#'
#'     Barros, J. A. (1994). Avaliação pulmonar pré-operatória em
#'     candidatos a cirurgia geral eletiva, Dissertação de mestrado,
#'     Escola Paulista de Medicina, Universidade Federal de São Paulo.
#' @examples
#'
#' xt <- xtabs(npaci ~ preop + posop, data = PaulinoTb6.2)
#' xt
#'
#' mosaicplot(xt, main = NULL,
#'            xlab = "Avaliação pré-operatória",
#'            ylab = "Avaliação pós-operatória")
#'
#' library(lattice)
#' 
#' barchart(xt,
#'          horizontal = FALSE,
#'          beside = FALSE,
#'          stack = FALSE,
#'          auto.key = list(space = "top", columns = 2,
#'                          cex.title = 1, rectangles = TRUE,
#'                          points = FALSE,
#'                          title = "Avaliação pós-operatória"),
#'          xlab = "Avaliação pré-operatória",
#'          ylab = "Frequência")
#'
NULL